@@ -501,9 +501,9 @@ class STFTAutoEncoder1d(AutoEncoder1d):
         self,
         in_channels: int,
         length: int,
-        num_fft: int = 1024,
+        num_fft: int = 1023,
         hop_length: int = 256,
-        window_length: int = 1024,
+        window_length: int = 1023,
         **kwargs,
     ):
         self.frequency_channels = num_fft // 2 + 1
@@ -536,9 +536,10 @@ class STFTAutoEncoder1d(AutoEncoder1d):
         stft = super().decode(z)
         stft = rearrange(stft, "b (c f i) t -> b (c i) f t", i=2, f=f)
         log_magnitude, phase = stft.chunk(chunks=2, dim=1)
+        log_magnitude = torch.clamp(log_magnitude, -30.0, 20.0)
         magnitude = torch.exp(log_magnitude)
         wave = self.stft.decode(magnitude, phase)
-        info = dict(magnitude=magnitude, phase=phase)
+        info = dict(log_magnitude=log_magnitude, phase=phase)
         return (wave, info) if with_info else wave
 
 
@@ -645,7 +646,7 @@ class Discriminator1d(nn.Module):
                 # Generator must match features with true sample and fool discriminator
                 loss_gs += [F.l1_loss(feat_true, feat_fake) - score_fake.mean()]
                 # Discriminator must give high score to true samples, low to fake
-                loss_ds += [((1 - score_true).relu() - (1 + score_fake).relu()).mean()]
+                loss_ds += [((1 - score_true).relu() + (1 + score_fake).relu()).mean()]
                 # Save scores
                 scores_true += [score_true.mean()]
                 scores_fake += [score_fake.mean()]
